from distutils.core import setup

setup(
    name="haha_list",
    version="1.2.0",
    py_modules=['print_list'],
    author="lile",
    author_email="836217653@qq.com",
    url = "http://www.cnblogs.com/lemon-le/",
    description="A simple printer of print_list lists"
)
